summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-03-19 06:19:40 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-03-19 18:16:05 -0500
commit5a13159bfcd42c0092472150c4d22589dea7931e (patch)
tree71a65f63b8e9a64e001b4fd4d83aed539eb19e57 /png.h
parentae1b45a04699235546b4d725aa4eceec138ffacd (diff)
downloadlibpng-5a13159bfcd42c0092472150c4d22589dea7931e.tar.gz
[master] Imported from libpng-1.5.10rc01.tar
Diffstat (limited to 'png.h')
-rw-r--r--png.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/png.h b/png.h
index 2ae668631..6eca5caf9 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.10beta04 - March 10, 2012
* Copyright (c) 1998-2012 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.10beta04 - March 10, 2012: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -172,7 +172,7 @@
* 1.5.9beta01-02 15 10509 15.so.15.9[.0]
* 1.5.9rc01 15 10509 15.so.15.9[.0]
* 1.5.9 15 10509 15.so.15.9[.0]
- * 1.5.10beta01-03 15 10510 15.so.15.10[.0]
+ * 1.5.10beta01-05 15 10510 15.so.15.10[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -204,7 +204,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.10beta04, March 10, 2012, are
* Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -316,13 +316,13 @@
* Y2K compliance in libpng:
* =========================
*
- * March 10, 2012
+ * March 19, 2012
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.10beta04 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -380,9 +380,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.10beta04"
+#define PNG_LIBPNG_VER_STRING "1.5.10rc01"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.10beta04 - March 10, 2012\n"
+ " libpng version 1.5.10rc01 - March 19, 2012\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -396,7 +396,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 04
+#define PNG_LIBPNG_VER_BUILD 01
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -413,7 +413,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_RC
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -543,7 +543,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_10beta04;
+typedef char* png_libpng_version_1_5_10rc01;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.10beta04 - March 10, 2012
+ * libpng version 1.5.10rc01 - March 19, 2012
* Copyright (c) 1998-2012 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.10beta04 - March 10, 2012: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.10rc01 - March 19, 2012: Glenn
* See also "Contributing Authors", below.
*
@@ -204,7 +204,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.10beta04, March 10, 2012, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.10rc01, March 19, 2012, are
* Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -316,13 +316,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.10beta04 are Y2K compliant. It is my belief that
+ * upward through 1.5.10rc01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*